@@ -1,15 +1,15 @@
 from typing import List, Optional, Dict
-from datasets import load_dataset
-import pandas as pd
 from tqdm import tqdm
 
 from deepeval.dataset import Golden
-from deepeval.benchmarks.base_benchmark import DeepEvalBaseBenchmark
+from deepeval.benchmarks.base_benchmark import (
+    DeepEvalBaseBenchmark,
+    DeepEvalBaseBenchmarkResult,
+)
 from deepeval.models import DeepEvalBaseLLM
 from deepeval.benchmarks.big_bench_hard.task import BigBenchHardTask
 from deepeval.benchmarks.big_bench_hard.template import BigBenchHardTemplate
 from deepeval.benchmarks.utils import should_use_batch
-from deepeval.scorer import Scorer
 from deepeval.benchmarks.schema import *
 from deepeval.telemetry import capture_benchmark_run
 
@@ -18,7 +18,7 @@ bbh_confinement_statements_dict = {
     BigBenchHardTask.CAUSAL_JUDGEMENT: "\n\nOutput 'Yes' or 'No'. Full answer not needed.",
     BigBenchHardTask.DATE_UNDERSTANDING: "\n\nOutput '(A)', '(B)', '(C)', '(D)', '(E)', or '(F)'. Full answer not needed.",
     BigBenchHardTask.DISAMBIGUATION_QA: "\n\nOutput '(A)', '(B)', or '(C)'. Full answer not needed.",
-    BigBenchHardTask.DYCK_LANGUAGES: "\n\nOutput only the sequence of parenthases characters separated by white space. Full answer not needed.",
+    BigBenchHardTask.DYCK_LANGUAGES: "\n\nOutput only the sequence of parentheses characters separated by white space. Full answer not needed.",
     BigBenchHardTask.FORMAL_FALLACIES: "\n\nOutput 'invalid' or 'valid'. Full answer not needed.",
     BigBenchHardTask.GEOMETRIC_SHAPES: "\n\nOutput '(A)', '(B)', '(C)', '(D)', '(E)', '(F)', '(G)', '(H)', '(I)', '(J)', or '(K)'. Full answer not needed.",
     BigBenchHardTask.HYPERBATON: "\n\nOutput '(A)' or'(B)'. Full answer not needed.",
@@ -57,6 +57,9 @@ class BigBenchHard(DeepEvalBaseBenchmark):
         ] = None,
         **kwargs,
     ):
+        from deepeval.scorer import Scorer
+        import pandas as pd
+
         assert n_shots <= 3, "BBH only supports n_shots <= 3"
         super().__init__(**kwargs)
         self.tasks: List[BigBenchHardTask] = (
@@ -76,8 +79,14 @@ class BigBenchHard(DeepEvalBaseBenchmark):
             self.confinement_instructions_dict = confinement_instructions_dict
 
     def evaluate(
-        self, model: DeepEvalBaseLLM, batch_size: Optional[int] = None
-    ) -> Dict:
+        self,
+        model: DeepEvalBaseLLM,
+        *args,
+        batch_size: Optional[int] = None,
+        **kwargs,
+    ) -> DeepEvalBaseBenchmarkResult:
+        import pandas as pd
+
         with capture_benchmark_run("Big Bench Hard", len(self.tasks)):
             overall_correct_predictions = 0
             overall_total_predictions = 0
@@ -183,7 +192,9 @@ class BigBenchHard(DeepEvalBaseBenchmark):
             )
             self.overall_score = overall_accuracy
 
-            return overall_accuracy
+            return DeepEvalBaseBenchmarkResult(
+                overall_accuracy=overall_accuracy
+            )
 
     def predict(
         self, model: DeepEvalBaseLLM, task: BigBenchHardTask, golden: Golden
@@ -199,7 +210,7 @@ class BigBenchHard(DeepEvalBaseBenchmark):
         try:
             res = model.generate(prompt=prompt, schema=pydantic_model)
             prediction = str(res.answer)
-        except TypeError:
+        except (AttributeError, TypeError):
             prompt += self.confinement_instructions_dict[task]
             prediction = model.generate(prompt)
 
@@ -265,15 +276,15 @@ class BigBenchHard(DeepEvalBaseBenchmark):
         return res
 
     def load_benchmark_dataset(self, task: BigBenchHardTask) -> List[Golden]:
+        from datasets import load_dataset
+
         dataset_mapping = {
             task: f"{task.value}_dataset" for task in BigBenchHardTask
         }
         dataset_attr = dataset_mapping.get(task)
         if dataset_attr:
             if not hasattr(self, dataset_attr):
-                dataset = load_dataset(
-                    "lukaemon/bbh", task.value, trust_remote_code=True
-                )
+                dataset = load_dataset("lukaemon/bbh", task.value)
                 setattr(self, dataset_attr, dataset)
             else:
                 dataset = getattr(self, dataset_attr)
