@@ -1,13 +1,13 @@
-from typing import List, Optional, Dict
-from datasets import load_dataset
-import pandas as pd
+from typing import List, Optional, Dict, Union
 from tqdm import tqdm
 
 from deepeval.dataset import Golden
-from deepeval.benchmarks.base_benchmark import DeepEvalBaseBenchmark
+from deepeval.benchmarks.base_benchmark import (
+    DeepEvalBaseBenchmark,
+    DeepEvalBaseBenchmarkResult,
+)
 from deepeval.models import DeepEvalBaseLLM
 from deepeval.benchmarks.gsm8k.template import GSM8KTemplate
-from deepeval.scorer import Scorer
 from deepeval.benchmarks.schema import NumberSchema
 from deepeval.telemetry import capture_benchmark_run
 
@@ -22,6 +22,9 @@ class GSM8K(DeepEvalBaseBenchmark):
         confinement_instructions: Optional[str] = None,
         **kwargs,
     ):
+        from deepeval.scorer import Scorer
+        import pandas as pd
+
         assert n_shots <= 15, "GSM8K only supports n_shots <= 15"
         super().__init__(**kwargs)
         self.scorer = Scorer()
@@ -39,7 +42,11 @@ class GSM8K(DeepEvalBaseBenchmark):
         else:
             self.confinement_instructions = confinement_instructions
 
-    def evaluate(self, model: DeepEvalBaseLLM) -> Dict:
+    def evaluate(
+        self, model: DeepEvalBaseLLM, *args, **kwargs
+    ) -> DeepEvalBaseBenchmarkResult:
+        import pandas as pd
+
         with capture_benchmark_run("GSM8K", len(self.tasks)):
             overall_correct_predictions = 0
             overall_total_predictions = self.n_problems
@@ -50,7 +57,10 @@ class GSM8K(DeepEvalBaseBenchmark):
             for idx, golden in enumerate(
                 tqdm(goldens, desc=f"Processing {self.n_problems} problems")
             ):
-                prediction, score = self.predict(model, golden).values()
+                result = self.predict(model, golden)
+                prediction = result["prediction"]
+                score = result["score"]
+
                 if score:
                     overall_correct_predictions += 1
                 predictions_row.append(
@@ -77,7 +87,9 @@ class GSM8K(DeepEvalBaseBenchmark):
             )
             self.overall_score = overall_accuracy
 
-            return overall_accuracy
+            return DeepEvalBaseBenchmarkResult(
+                overall_accuracy=overall_accuracy
+            )
 
     def predict(self, model: DeepEvalBaseLLM, golden: Golden) -> Dict:
         # Define prompt template
@@ -92,14 +104,17 @@ class GSM8K(DeepEvalBaseBenchmark):
         )
 
         # Enforced model generation
+        prediction = None
         try:
             res: NumberSchema = model.generate(
                 prompt=prompt, schema=NumberSchema
             )
-            prediction = str(res.answer)
-        except TypeError:
+            prediction = self._extract_prediction_from_response(res)
+        except (TypeError, AttributeError) as e:
+
             prompt += f"\n\n{self.confinement_instructions}"
-            prediction = model.generate(prompt)
+            res = model.generate(prompt)
+            prediction = self._extract_prediction_from_response(res)
 
         # For native models, shouldn't happen but just in case
         if isinstance(prediction, tuple):
@@ -112,12 +127,37 @@ class GSM8K(DeepEvalBaseBenchmark):
 
         return {"prediction": prediction, "score": score}
 
+    def _extract_prediction_from_response(self, res) -> str:
+        """
+        Extract prediction from model response, handling various response types.
+        """
+        # Case 1: Response has .answer attribute (NumberSchema case)
+        if hasattr(res, "answer"):
+            return str(res.answer)
+
+        # Case 2: Response is a tuple
+        elif isinstance(res, tuple):
+            return self._extract_from_tuple(res)
+
+        else:
+            return str(res)
+
+    def _extract_from_tuple(self, res: tuple) -> str:
+        """Extract prediction from tuple response."""
+        if len(res) == 0:
+            return ""
+        first_elem = res[0]
+        if hasattr(first_elem, "answer"):
+            return str(first_elem.answer)
+
     def load_benchmark_dataset(self) -> List[Golden]:
+        from datasets import load_dataset
+
         # Load dataset
         if self.dataset:
             dataset = self.dataset
         else:
-            dataset = load_dataset("gsm8k", "main", trust_remote_code=True)
+            dataset = load_dataset("gsm8k", "main")
             self.dataset = dataset
 
         # Construct example dataset for n_shot inference
