@@ -7,11 +7,7 @@ def should_use_batch(model: DeepEvalBaseLLM, batch_size: Optional[int] = None):
     if batch_size is None:
         return False
 
-    try:
-        model.batch_generate([""])
-    except Exception as AttributeError:
+    if not hasattr(model, "batch_generate"):
         return False
-    except:
-        raise
 
     return True
