@@ -2,19 +2,20 @@ import time
 import pytest
 import typer
 import os
-import json
 import sys
 from typing_extensions import Annotated
 from typing import Optional
 
-from deepeval.test_run import global_test_run_manager, TEMP_FILE_NAME
+from deepeval.test_run import global_test_run_manager, TEMP_FILE_PATH
 from deepeval.test_run.cache import TEMP_CACHE_FILE_NAME
+from deepeval.test_run.test_run import TestRunResultDisplay
 from deepeval.utils import (
     delete_file_if_exists,
     set_should_ignore_errors,
     set_should_skip_on_missing_params,
     set_should_use_cache,
     set_verbose_mode,
+    set_identifier,
 )
 from deepeval.test_run import invoke_test_run_end_hook
 from deepeval.telemetry import capture_evaluation_run
@@ -40,8 +41,12 @@ def check_if_valid_file(test_file_or_directory: str):
         )
 
 
-@app.command()
+# Allow extra args and ignore unknown options allow extra args to be passed to pytest
+@app.command(
+    context_settings={"allow_extra_args": True, "ignore_unknown_options": True}
+)
 def run(
+    ctx: typer.Context,
     test_file_or_directory: str,
     color: str = "yes",
     durations: int = 10,
@@ -94,6 +99,13 @@ def run(
         "-v",
         help="Whether to turn on verbose mode for evaluation or not",
     ),
+    display: Optional[TestRunResultDisplay] = typer.Option(
+        TestRunResultDisplay.ALL.value,
+        "--display",
+        "-d",
+        help="Whether to display all test cases or just some in the end",
+        case_sensitive=False,
+    ),
     mark: Optional[str] = typer.Option(
         None,
         "--mark",
@@ -102,7 +114,7 @@ def run(
     ),
 ):
     """Run a test"""
-    delete_file_if_exists(TEMP_FILE_NAME)
+    delete_file_if_exists(TEMP_FILE_PATH)
     delete_file_if_exists(TEMP_CACHE_FILE_NAME)
     check_if_valid_file(test_file_or_directory)
     set_is_running_deepeval(True)
@@ -112,6 +124,7 @@ def run(
     set_should_ignore_errors(ignore_errors)
     set_should_skip_on_missing_params(skip_on_missing_params)
     set_verbose_mode(verbose)
+    set_identifier(identifier)
 
     global_test_run_manager.reset()
 
@@ -148,13 +161,17 @@ def run(
 
     # Add the deepeval plugin file to pytest arguments
     pytest_args.extend(["-p", "plugins"])
+    # Append the extra arguments collected by allow_extra_args=True
+    # Pytest will raise its own error if the arguments are invalid (error:
+    if ctx.args:
+        pytest_args.extend(ctx.args)
 
     start_time = time.perf_counter()
     with capture_evaluation_run("deepeval test run"):
         pytest_retcode = pytest.main(pytest_args)
     end_time = time.perf_counter()
     run_duration = end_time - start_time
-    global_test_run_manager.wrap_up_test_run(run_duration)
+    global_test_run_manager.wrap_up_test_run(run_duration, True, display)
 
     invoke_test_run_end_hook()
 
