@@ -1,4 +1,4 @@
-from typing import Optional, List, Union
+from typing import Optional, List, Type, Union
 
 from deepeval.utils import get_or_create_event_loop, prettify_list
 from deepeval.metrics.utils import (
@@ -10,7 +10,6 @@ from deepeval.metrics.utils import (
 from deepeval.test_case import (
     LLMTestCase,
     LLMTestCaseParams,
-    ConversationalTestCase,
 )
 from deepeval.metrics import BaseMetric
 from deepeval.models import DeepEvalBaseLLM
@@ -18,13 +17,13 @@ from deepeval.metrics.answer_relevancy.template import AnswerRelevancyTemplate
 from deepeval.metrics.indicator import metric_progress_indicator
 from deepeval.metrics.answer_relevancy.schema import *
 
-required_params: List[LLMTestCaseParams] = [
-    LLMTestCaseParams.INPUT,
-    LLMTestCaseParams.ACTUAL_OUTPUT,
-]
-
 
 class AnswerRelevancyMetric(BaseMetric):
+    _required_params: List[LLMTestCaseParams] = [
+        LLMTestCaseParams.INPUT,
+        LLMTestCaseParams.ACTUAL_OUTPUT,
+    ]
+
     def __init__(
         self,
         threshold: float = 0.5,
@@ -33,6 +32,9 @@ class AnswerRelevancyMetric(BaseMetric):
         async_mode: bool = True,
         strict_mode: bool = False,
         verbose_mode: bool = False,
+        evaluation_template: Type[
+            AnswerRelevancyTemplate
+        ] = AnswerRelevancyTemplate,
     ):
         self.threshold = 1 if strict_mode else threshold
         self.model, self.using_native_model = initialize_model(model)
@@ -41,28 +43,35 @@ class AnswerRelevancyMetric(BaseMetric):
         self.async_mode = async_mode
         self.strict_mode = strict_mode
         self.verbose_mode = verbose_mode
+        self.evaluation_template = evaluation_template
 
     def measure(
         self,
-        test_case: Union[LLMTestCase, ConversationalTestCase],
+        test_case: LLMTestCase,
         _show_indicator: bool = True,
+        _in_component: bool = False,
     ) -> float:
-        if isinstance(test_case, ConversationalTestCase):
-            test_case = test_case.turns[0]
-        check_llm_test_case_params(test_case, required_params, self)
+
+        check_llm_test_case_params(test_case, self._required_params, self)
 
         self.evaluation_cost = 0 if self.using_native_model else None
-        with metric_progress_indicator(self, _show_indicator=_show_indicator):
+        with metric_progress_indicator(
+            self, _show_indicator=_show_indicator, _in_component=_in_component
+        ):
             if self.async_mode:
                 loop = get_or_create_event_loop()
                 loop.run_until_complete(
-                    self.a_measure(test_case, _show_indicator=False)
+                    self.a_measure(
+                        test_case,
+                        _show_indicator=False,
+                        _in_component=_in_component,
+                    )
                 )
             else:
                 self.statements: List[str] = self._generate_statements(
                     test_case.actual_output
                 )
-                self.verdicts: List[AnswerRelvancyVerdict] = (
+                self.verdicts: List[AnswerRelevancyVerdict] = (
                     self._generate_verdicts(test_case.input)
                 )
                 self.score = self._calculate_score()
@@ -77,25 +86,28 @@ class AnswerRelevancyMetric(BaseMetric):
                     ],
                 )
 
-                return self.score
+            return self.score
 
     async def a_measure(
         self,
-        test_case: Union[LLMTestCase, ConversationalTestCase],
+        test_case: LLMTestCase,
         _show_indicator: bool = True,
+        _in_component: bool = False,
     ) -> float:
-        if isinstance(test_case, ConversationalTestCase):
-            test_case = test_case.turns[0]
-        check_llm_test_case_params(test_case, required_params, self)
+
+        check_llm_test_case_params(test_case, self._required_params, self)
 
         self.evaluation_cost = 0 if self.using_native_model else None
         with metric_progress_indicator(
-            self, async_mode=True, _show_indicator=_show_indicator
+            self,
+            async_mode=True,
+            _show_indicator=_show_indicator,
+            _in_component=_in_component,
         ):
             self.statements: List[str] = await self._a_generate_statements(
                 test_case.actual_output
             )
-            self.verdicts: List[AnswerRelvancyVerdict] = (
+            self.verdicts: List[AnswerRelevancyVerdict] = (
                 await self._a_generate_verdicts(test_case.input)
             )
             self.score = self._calculate_score()
@@ -121,19 +133,21 @@ class AnswerRelevancyMetric(BaseMetric):
             if verdict.verdict.strip().lower() == "no":
                 irrelevant_statements.append(verdict.reason)
 
-        prompt = AnswerRelevancyTemplate.generate_reason(
+        prompt = self.evaluation_template.generate_reason(
             irrelevant_statements=irrelevant_statements,
             input=input,
             score=format(self.score, ".2f"),
         )
         if self.using_native_model:
-            res, cost = await self.model.a_generate(prompt, schema=Reason)
+            res, cost = await self.model.a_generate(
+                prompt, schema=AnswerRelevancyScoreReason
+            )
             self.evaluation_cost += cost
             return res.reason
         else:
             try:
-                res: Reason = await self.model.a_generate(
-                    prompt=prompt, schema=Reason
+                res: AnswerRelevancyScoreReason = await self.model.a_generate(
+                    prompt=prompt, schema=AnswerRelevancyScoreReason
                 )
                 return res.reason
             except TypeError:
@@ -150,19 +164,23 @@ class AnswerRelevancyMetric(BaseMetric):
             if verdict.verdict.strip().lower() == "no":
                 irrelevant_statements.append(verdict.reason)
 
-        prompt = AnswerRelevancyTemplate.generate_reason(
+        prompt = self.evaluation_template.generate_reason(
             irrelevant_statements=irrelevant_statements,
             input=input,
             score=format(self.score, ".2f"),
         )
 
         if self.using_native_model:
-            res, cost = self.model.generate(prompt, schema=Reason)
+            res, cost = self.model.generate(
+                prompt, schema=AnswerRelevancyScoreReason
+            )
             self.evaluation_cost += cost
             return res.reason
         else:
             try:
-                res: Reason = self.model.generate(prompt=prompt, schema=Reason)
+                res: AnswerRelevancyScoreReason = self.model.generate(
+                    prompt=prompt, schema=AnswerRelevancyScoreReason
+                )
                 return res.reason
             except TypeError:
                 res = self.model.generate(prompt)
@@ -171,14 +189,15 @@ class AnswerRelevancyMetric(BaseMetric):
 
     async def _a_generate_verdicts(
         self, input: str
-    ) -> List[AnswerRelvancyVerdict]:
+    ) -> List[AnswerRelevancyVerdict]:
         if len(self.statements) == 0:
             return []
 
-        prompt = AnswerRelevancyTemplate.generate_verdicts(
+        prompt = self.evaluation_template.generate_verdicts(
             input=input,
-            actual_output=self.statements,
+            statements=self.statements,
         )
+
         if self.using_native_model:
             res, cost = await self.model.a_generate(prompt, schema=Verdicts)
             self.evaluation_cost += cost
@@ -193,16 +212,16 @@ class AnswerRelevancyMetric(BaseMetric):
                 res = await self.model.a_generate(prompt)
                 data = trimAndLoadJson(res, self)
                 return [
-                    AnswerRelvancyVerdict(**item) for item in data["verdicts"]
+                    AnswerRelevancyVerdict(**item) for item in data["verdicts"]
                 ]
 
-    def _generate_verdicts(self, input: str) -> List[AnswerRelvancyVerdict]:
+    def _generate_verdicts(self, input: str) -> List[AnswerRelevancyVerdict]:
         if len(self.statements) == 0:
             return []
 
-        prompt = AnswerRelevancyTemplate.generate_verdicts(
+        prompt = self.evaluation_template.generate_verdicts(
             input=input,
-            actual_output=self.statements,
+            statements=self.statements,
         )
         if self.using_native_model:
             res, cost = self.model.generate(prompt, schema=Verdicts)
@@ -216,14 +235,14 @@ class AnswerRelevancyMetric(BaseMetric):
                 res = self.model.generate(prompt)
                 data = trimAndLoadJson(res, self)
                 return [
-                    AnswerRelvancyVerdict(**item) for item in data["verdicts"]
+                    AnswerRelevancyVerdict(**item) for item in data["verdicts"]
                 ]
 
     async def _a_generate_statements(
         self,
         actual_output: str,
     ) -> List[str]:
-        prompt = AnswerRelevancyTemplate.generate_statements(
+        prompt = self.evaluation_template.generate_statements(
             actual_output=actual_output,
         )
         if self.using_native_model:
@@ -245,7 +264,7 @@ class AnswerRelevancyMetric(BaseMetric):
         self,
         actual_output: str,
     ) -> List[str]:
-        prompt = AnswerRelevancyTemplate.generate_statements(
+        prompt = self.evaluation_template.generate_statements(
             actual_output=actual_output,
         )
         if self.using_native_model:
