@@ -1,10 +1,9 @@
-from typing import List, Optional, Union
+from typing import List, Optional, Type, Union
 
 from deepeval.metrics import BaseMetric
 from deepeval.test_case import (
     LLMTestCase,
     LLMTestCaseParams,
-    ConversationalTestCase,
 )
 from deepeval.metrics.indicator import metric_progress_indicator
 from deepeval.models import DeepEvalBaseLLM
@@ -18,13 +17,13 @@ from deepeval.metrics.utils import (
 from deepeval.metrics.bias.template import BiasTemplate
 from deepeval.metrics.bias.schema import *
 
-required_params: List[LLMTestCaseParams] = [
-    LLMTestCaseParams.INPUT,
-    LLMTestCaseParams.ACTUAL_OUTPUT,
-]
-
 
 class BiasMetric(BaseMetric):
+    _required_params: List[LLMTestCaseParams] = [
+        LLMTestCaseParams.INPUT,
+        LLMTestCaseParams.ACTUAL_OUTPUT,
+    ]
+
     def __init__(
         self,
         threshold: float = 0.5,
@@ -33,6 +32,7 @@ class BiasMetric(BaseMetric):
         async_mode: bool = True,
         strict_mode: bool = False,
         verbose_mode: bool = False,
+        evaluation_template: Type[BiasTemplate] = BiasTemplate,
     ):
         self.threshold = 0 if strict_mode else threshold
         self.model, self.using_native_model = initialize_model(model)
@@ -41,22 +41,29 @@ class BiasMetric(BaseMetric):
         self.async_mode = async_mode
         self.strict_mode = strict_mode
         self.verbose_mode = verbose_mode
+        self.evaluation_template = evaluation_template
 
     def measure(
         self,
-        test_case: Union[LLMTestCase, ConversationalTestCase],
+        test_case: LLMTestCase,
         _show_indicator: bool = True,
+        _in_component: bool = False,
     ) -> float:
-        if isinstance(test_case, ConversationalTestCase):
-            test_case = test_case.turns[0]
-        check_llm_test_case_params(test_case, required_params, self)
+
+        check_llm_test_case_params(test_case, self._required_params, self)
 
         self.evaluation_cost = 0 if self.using_native_model else None
-        with metric_progress_indicator(self, _show_indicator=_show_indicator):
+        with metric_progress_indicator(
+            self, _show_indicator=_show_indicator, _in_component=_in_component
+        ):
             if self.async_mode:
                 loop = get_or_create_event_loop()
                 loop.run_until_complete(
-                    self.a_measure(test_case, _show_indicator=False)
+                    self.a_measure(
+                        test_case,
+                        _show_indicator=False,
+                        _in_component=_in_component,
+                    )
                 )
             else:
                 self.opinions: List[str] = self._generate_opinions(
@@ -75,22 +82,23 @@ class BiasMetric(BaseMetric):
                     ],
                 )
 
-                return self.score
+            return self.score
 
     async def a_measure(
         self,
-        test_case: Union[LLMTestCase, ConversationalTestCase],
+        test_case: LLMTestCase,
         _show_indicator: bool = True,
+        _in_component: bool = False,
     ) -> float:
-        if isinstance(test_case, ConversationalTestCase):
-            test_case = test_case.turns[0]
-        check_llm_test_case_params(test_case, required_params, self)
+
+        check_llm_test_case_params(test_case, self._required_params, self)
 
         self.evaluation_cost = 0 if self.using_native_model else None
         with metric_progress_indicator(
             self,
             async_mode=True,
             _show_indicator=_show_indicator,
+            _in_component=_in_component,
         ):
             self.opinions: List[str] = await self._a_generate_opinions(
                 test_case.actual_output
@@ -119,18 +127,22 @@ class BiasMetric(BaseMetric):
             if verdict.verdict.strip().lower() == "yes":
                 biases.append(verdict.reason)
 
-        prompt: dict = BiasTemplate.generate_reason(
+        prompt: dict = self.evaluation_template.generate_reason(
             biases=biases,
             score=format(self.score, ".2f"),
         )
 
         if self.using_native_model:
-            res, cost = await self.model.a_generate(prompt, schema=Reason)
+            res, cost = await self.model.a_generate(
+                prompt, schema=BiasScoreReason
+            )
             self.evaluation_cost += cost
             return res.reason
         else:
             try:
-                res: Reason = await self.model.a_generate(prompt, schema=Reason)
+                res: BiasScoreReason = await self.model.a_generate(
+                    prompt, schema=BiasScoreReason
+                )
                 return res.reason
             except TypeError:
                 res = await self.model.a_generate(prompt)
@@ -146,18 +158,20 @@ class BiasMetric(BaseMetric):
             if verdict.verdict.strip().lower() == "yes":
                 biases.append(verdict.reason)
 
-        prompt: dict = BiasTemplate.generate_reason(
+        prompt: dict = self.evaluation_template.generate_reason(
             biases=biases,
             score=format(self.score, ".2f"),
         )
 
         if self.using_native_model:
-            res, cost = self.model.generate(prompt, schema=Reason)
+            res, cost = self.model.generate(prompt, schema=BiasScoreReason)
             self.evaluation_cost += cost
             return res.reason
         else:
             try:
-                res: Reason = self.model.generate(prompt, schema=Reason)
+                res: BiasScoreReason = self.model.generate(
+                    prompt, schema=BiasScoreReason
+                )
                 return res.reason
             except TypeError:
                 res = self.model.generate(prompt)
@@ -169,7 +183,9 @@ class BiasMetric(BaseMetric):
             return []
 
         verdicts: List[BiasVerdict] = []
-        prompt = BiasTemplate.generate_verdicts(opinions=self.opinions)
+        prompt = self.evaluation_template.generate_verdicts(
+            opinions=self.opinions
+        )
         if self.using_native_model:
             res, cost = await self.model.a_generate(prompt, schema=Verdicts)
             self.evaluation_cost += cost
@@ -193,9 +209,11 @@ class BiasMetric(BaseMetric):
             return []
 
         verdicts: List[BiasVerdict] = []
-        prompt = BiasTemplate.generate_verdicts(opinions=self.opinions)
+        prompt = self.evaluation_template.generate_verdicts(
+            opinions=self.opinions
+        )
         if self.using_native_model:
-            res, cost = self.model.generate(prompt, schema=BiasVerdict)
+            res, cost = self.model.generate(prompt, schema=Verdicts)
             self.evaluation_cost += cost
             verdicts = [item for item in res.verdicts]
             return verdicts
@@ -211,7 +229,9 @@ class BiasMetric(BaseMetric):
                 return verdicts
 
     async def _a_generate_opinions(self, actual_output: str) -> List[str]:
-        prompt = BiasTemplate.generate_opinions(actual_output=actual_output)
+        prompt = self.evaluation_template.generate_opinions(
+            actual_output=actual_output
+        )
         if self.using_native_model:
             res, cost = await self.model.a_generate(prompt, schema=Opinions)
             self.evaluation_cost += cost
@@ -228,7 +248,9 @@ class BiasMetric(BaseMetric):
                 return data["opinions"]
 
     def _generate_opinions(self, actual_output: str) -> List[str]:
-        prompt = BiasTemplate.generate_opinions(actual_output=actual_output)
+        prompt = self.evaluation_template.generate_opinions(
+            actual_output=actual_output
+        )
         if self.using_native_model:
             res, cost = self.model.generate(prompt, schema=Opinions)
             self.evaluation_cost += cost
