@@ -1,9 +1,8 @@
-from typing import Optional, Union, List
+from typing import Optional, Type, Union, List
 
 from deepeval.test_case import (
     LLMTestCase,
     LLMTestCaseParams,
-    ConversationalTestCase,
 )
 from deepeval.metrics import BaseMetric
 from deepeval.utils import get_or_create_event_loop, prettify_list
@@ -34,6 +33,9 @@ class HallucinationMetric(BaseMetric):
         async_mode: bool = False,
         strict_mode: bool = False,
         verbose_mode: bool = False,
+        evaluation_template: Type[
+            HallucinationTemplate
+        ] = HallucinationTemplate,
     ):
         self.threshold = 0 if strict_mode else threshold
         self.model, self.using_native_model = initialize_model(model)
@@ -42,22 +44,29 @@ class HallucinationMetric(BaseMetric):
         self.async_mode = async_mode
         self.strict_mode = strict_mode
         self.verbose_mode = verbose_mode
+        self.evaluation_template = evaluation_template
 
     def measure(
         self,
-        test_case: Union[LLMTestCase, ConversationalTestCase],
+        test_case: LLMTestCase,
         _show_indicator: bool = True,
+        _in_component: bool = False,
     ) -> float:
-        if isinstance(test_case, ConversationalTestCase):
-            test_case = test_case.turns[0]
+
         check_llm_test_case_params(test_case, required_params, self)
 
         self.evaluation_cost = 0 if self.using_native_model else None
-        with metric_progress_indicator(self, _show_indicator=_show_indicator):
+        with metric_progress_indicator(
+            self, _show_indicator=_show_indicator, _in_component=_in_component
+        ):
             if self.async_mode:
                 loop = get_or_create_event_loop()
                 loop.run_until_complete(
-                    self.a_measure(test_case, _show_indicator=False)
+                    self.a_measure(
+                        test_case,
+                        _show_indicator=False,
+                        _in_component=_in_component,
+                    )
                 )
             else:
                 self.verdicts: List[HallucinationVerdict] = (
@@ -76,20 +85,23 @@ class HallucinationMetric(BaseMetric):
                     ],
                 )
 
-                return self.score
+            return self.score
 
     async def a_measure(
         self,
-        test_case: Union[LLMTestCase, ConversationalTestCase],
+        test_case: LLMTestCase,
         _show_indicator: bool = True,
+        _in_component: bool = False,
     ) -> float:
-        if isinstance(test_case, ConversationalTestCase):
-            test_case = test_case.turns[0]
+
         check_llm_test_case_params(test_case, required_params, self)
 
         self.evaluation_cost = 0 if self.using_native_model else None
         with metric_progress_indicator(
-            self, async_mode=True, _show_indicator=_show_indicator
+            self,
+            async_mode=True,
+            _show_indicator=_show_indicator,
+            _in_component=_in_component,
         ):
             self.verdicts: List[HallucinationVerdict] = (
                 await self._a_generate_verdicts(
@@ -121,19 +133,23 @@ class HallucinationMetric(BaseMetric):
             else:
                 contradictions.append(verdict.reason)
 
-        prompt: dict = HallucinationTemplate.generate_reason(
+        prompt: dict = self.evaluation_template.generate_reason(
             factual_alignments=factual_alignments,
             contradictions=contradictions,
             score=format(self.score, ".2f"),
         )
 
         if self.using_native_model:
-            res, cost = await self.model.a_generate(prompt, schema=Reason)
+            res, cost = await self.model.a_generate(
+                prompt, schema=HallucinationScoreReason
+            )
             self.evaluation_cost += cost
             return res.reason
         else:
             try:
-                res: Reason = await self.model.a_generate(prompt, schema=Reason)
+                res: HallucinationScoreReason = await self.model.a_generate(
+                    prompt, schema=HallucinationScoreReason
+                )
                 return res.reason
             except TypeError:
                 res = await self.model.a_generate(prompt)
@@ -152,19 +168,23 @@ class HallucinationMetric(BaseMetric):
             else:
                 contradictions.append(verdict.reason)
 
-        prompt: dict = HallucinationTemplate.generate_reason(
+        prompt: dict = self.evaluation_template.generate_reason(
             factual_alignments=factual_alignments,
             contradictions=contradictions,
             score=format(self.score, ".2f"),
         )
 
         if self.using_native_model:
-            res, cost = self.model.generate(prompt, schema=Reason)
+            res, cost = self.model.generate(
+                prompt, schema=HallucinationScoreReason
+            )
             self.evaluation_cost += cost
             return res.reason
         else:
             try:
-                res: Reason = self.model.generate(prompt, schema=Reason)
+                res: HallucinationScoreReason = self.model.generate(
+                    prompt, schema=HallucinationScoreReason
+                )
                 return res.reason
             except TypeError:
                 res = self.model.generate(prompt)
@@ -175,7 +195,7 @@ class HallucinationMetric(BaseMetric):
         self, actual_output: str, contexts: List[str]
     ) -> List[HallucinationVerdict]:
         verdicts: List[HallucinationVerdict] = []
-        prompt = HallucinationTemplate.generate_verdicts(
+        prompt = self.evaluation_template.generate_verdicts(
             actual_output=actual_output, contexts=contexts
         )
         if self.using_native_model:
@@ -202,7 +222,7 @@ class HallucinationMetric(BaseMetric):
         self, actual_output: str, contexts: List[str]
     ) -> List[HallucinationVerdict]:
         verdicts: List[HallucinationVerdict] = []
-        prompt = HallucinationTemplate.generate_verdicts(
+        prompt = self.evaluation_template.generate_verdicts(
             actual_output=actual_output, contexts=contexts
         )
         if self.using_native_model:
