@@ -1,5 +1,5 @@
 from rich.console import Console
-from rich.progress import Progress, SpinnerColumn, TextColumn
+from rich.progress import Progress, SpinnerColumn, TextColumn, BarColumn
 from contextlib import contextmanager
 import sys
 from typing import List, Optional, Union
@@ -11,14 +11,16 @@ from deepeval.metrics import (
     BaseMetric,
     BaseConversationalMetric,
     BaseMultimodalMetric,
+    BaseArenaMetric,
 )
 from deepeval.test_case import LLMTestCase, ConversationalTestCase, MLLMTestCase
 from deepeval.test_run.cache import CachedTestCase, Cache
 from deepeval.telemetry import capture_metric_type
+from deepeval.utils import update_pbar
 
 
 def format_metric_description(
-    metric: Union[BaseMetric, BaseConversationalMetric],
+    metric: Union[BaseMetric, BaseConversationalMetric, BaseArenaMetric],
     async_mode: Optional[bool] = None,
 ):
     if async_mode is None:
@@ -26,22 +28,32 @@ def format_metric_description(
     else:
         run_async = async_mode
 
-    return f"✨ You're running DeepEval's latest [rgb(106,0,255)]{metric.__name__} Metric[/rgb(106,0,255)]! [rgb(55,65,81)](using {metric.evaluation_model}, strict={metric.strict_mode}, async_mode={run_async})...[/rgb(55,65,81)]"
+    if isinstance(metric, BaseArenaMetric):
+        return f"✨ You're running DeepEval's latest [rgb(106,0,255)]{metric.__name__} Metric[/rgb(106,0,255)]! [rgb(55,65,81)](using {metric.evaluation_model}, async_mode={run_async})...[/rgb(55,65,81)]"
+    else:
+        return f"✨ You're running DeepEval's latest [rgb(106,0,255)]{metric.__name__} Metric[/rgb(106,0,255)]! [rgb(55,65,81)](using {metric.evaluation_model}, strict={metric.strict_mode}, async_mode={run_async})...[/rgb(55,65,81)]"
 
 
 @contextmanager
 def metric_progress_indicator(
     metric: BaseMetric,
     async_mode: Optional[bool] = None,
-    _show_indicator: bool = True,
     total: int = 9999,
     transient: bool = True,
+    _show_indicator: bool = True,
+    _in_component: bool = False,
 ):
-    with capture_metric_type(metric.__name__):
+    captured_async_mode = False if async_mode == None else async_mode
+    with capture_metric_type(
+        metric.__name__,
+        async_mode=captured_async_mode,
+        in_component=_in_component,
+    ):
         console = Console(file=sys.stderr)  # Direct output to standard error
         if _show_indicator:
             with Progress(
                 SpinnerColumn(style="rgb(106,0,255)"),
+                BarColumn(bar_width=60),
                 TextColumn("[progress.description]{task.description}"),
                 console=console,  # Use the custom console
                 transient=transient,
@@ -63,6 +75,7 @@ async def measure_metric_task(
     cached_test_case: Union[CachedTestCase, None],
     ignore_errors: bool,
     skip_on_missing_params: bool,
+    _in_component: bool = False,
 ):
     while not progress.finished:
         start_time = time.perf_counter()
@@ -83,7 +96,11 @@ async def measure_metric_task(
             finish_text = "Read from Cache"
         else:
             try:
-                await metric.a_measure(test_case, _show_indicator=False)
+                await metric.a_measure(
+                    test_case,
+                    _show_indicator=False,
+                    _in_component=_in_component,
+                )
                 finish_text = "Done"
             except MissingTestCaseParamsError as e:
                 if skip_on_missing_params:
@@ -98,7 +115,9 @@ async def measure_metric_task(
                         raise
             except TypeError:
                 try:
-                    await metric.a_measure(test_case)
+                    await metric.a_measure(
+                        test_case, _in_component=_in_component
+                    )
                     finish_text = "Done"
                 except MissingTestCaseParamsError as e:
                     if skip_on_missing_params:
@@ -138,10 +157,14 @@ async def measure_metrics_with_indicator(
     ignore_errors: bool,
     skip_on_missing_params: bool,
     show_indicator: bool,
+    progress: Optional[Progress] = None,
+    pbar_eval_id: Optional[int] = None,
+    _in_component: bool = False,
 ):
     if show_indicator:
         with Progress(
             SpinnerColumn(style="rgb(106,0,255)"),
+            BarColumn(bar_width=60),
             TextColumn("[progress.description]{task.description}"),
             transient=False,
         ) as progress:
@@ -162,6 +185,7 @@ async def measure_metrics_with_indicator(
                         cached_test_case,
                         ignore_errors,
                         skip_on_missing_params,
+                        _in_component=_in_component,
                     )
                 )
             await asyncio.gather(*tasks)
@@ -193,7 +217,13 @@ async def measure_metrics_with_indicator(
             else:
                 tasks.append(
                     safe_a_measure(
-                        metric, test_case, ignore_errors, skip_on_missing_params
+                        metric,
+                        test_case,
+                        ignore_errors,
+                        skip_on_missing_params,
+                        progress=progress,
+                        pbar_eval_id=pbar_eval_id,
+                        _in_component=_in_component,
                     )
                 )
 
@@ -205,9 +235,15 @@ async def safe_a_measure(
     tc: Union[LLMTestCase, MLLMTestCase, ConversationalTestCase],
     ignore_errors: bool,
     skip_on_missing_params: bool,
+    progress: Optional[Progress] = None,
+    pbar_eval_id: Optional[int] = None,
+    _in_component: bool = False,
 ):
     try:
-        await metric.a_measure(tc, _show_indicator=False)
+        await metric.a_measure(
+            tc, _show_indicator=False, _in_component=_in_component
+        )
+        update_pbar(progress, pbar_eval_id)
     except MissingTestCaseParamsError as e:
         if skip_on_missing_params:
             metric.skipped = True
