@@ -18,3 +18,7 @@ from .multimodal_answer_relevancy.multimodal_answer_relevancy import (
 from .multimodal_faithfulness.multimodal_faithfulness import (
     MultimodalFaithfulnessMetric,
 )
+from .multimodal_tool_correctness.multimodal_tool_correctness import (
+    MultimodalToolCorrectnessMetric,
+)
+from .multimodal_g_eval.multimodal_g_eval import MultimodalGEval
