@@ -18,16 +18,25 @@ from deepeval.metrics.utils import (
 from deepeval.metrics.summarization.template import SummarizationTemplate
 from deepeval.metrics.faithfulness.template import FaithfulnessTemplate
 from deepeval.metrics.indicator import metric_progress_indicator
-from deepeval.metrics.summarization.schema import *
-from deepeval.metrics.faithfulness.schema import *
-
-required_params: List[LLMTestCaseParams] = [
-    LLMTestCaseParams.INPUT,
-    LLMTestCaseParams.ACTUAL_OUTPUT,
-]
+from deepeval.metrics.summarization.schema import (
+    ScoreType,
+    SummarizationAlignmentVerdict,
+    SummarizationCoverageVerdict,
+    Verdicts,
+    Questions,
+    Answers,
+    SummarizationScoreReason,
+)
+from deepeval.metrics.faithfulness.schema import Truths, Claims
 
 
 class SummarizationMetric(BaseMetric):
+
+    _required_params: List[LLMTestCaseParams] = [
+        LLMTestCaseParams.INPUT,
+        LLMTestCaseParams.ACTUAL_OUTPUT,
+    ]
+
     def __init__(
         self,
         threshold: float = 0.5,
@@ -61,19 +70,25 @@ class SummarizationMetric(BaseMetric):
 
     def measure(
         self,
-        test_case: Union[LLMTestCase, ConversationalTestCase],
+        test_case: LLMTestCase,
         _show_indicator: bool = True,
+        _in_component: bool = False,
     ) -> float:
-        if isinstance(test_case, ConversationalTestCase):
-            test_case = test_case.turns[0]
-        check_llm_test_case_params(test_case, required_params, self)
+
+        check_llm_test_case_params(test_case, self._required_params, self)
 
         self.evaluation_cost = 0 if self.using_native_model else None
-        with metric_progress_indicator(self, _show_indicator=_show_indicator):
+        with metric_progress_indicator(
+            self, _show_indicator=_show_indicator, _in_component=_in_component
+        ):
             if self.async_mode:
                 loop = get_or_create_event_loop()
                 loop.run_until_complete(
-                    self.a_measure(test_case, _show_indicator=False)
+                    self.a_measure(
+                        test_case,
+                        _show_indicator=False,
+                        _in_component=_in_component,
+                    )
                 )
             else:
                 self.truths: List[str] = self._generate_truths(test_case.input)
@@ -107,22 +122,23 @@ class SummarizationMetric(BaseMetric):
                     ],
                 )
 
-                return self.score
+            return self.score
 
     async def a_measure(
         self,
-        test_case: Union[LLMTestCase, ConversationalTestCase],
+        test_case: LLMTestCase,
         _show_indicator: bool = True,
+        _in_component: bool = False,
     ) -> float:
-        if isinstance(test_case, ConversationalTestCase):
-            test_case = test_case.turns[0]
-        check_llm_test_case_params(test_case, required_params, self)
+
+        check_llm_test_case_params(test_case, self._required_params, self)
 
         self.evaluation_cost = 0 if self.using_native_model else None
         with metric_progress_indicator(
             self,
             async_mode=True,
             _show_indicator=_show_indicator,
+            _in_component=_in_component,
         ):
             self.truths, self.claims = await asyncio.gather(
                 self._a_generate_truths(test_case.input),
@@ -195,12 +211,16 @@ class SummarizationMetric(BaseMetric):
 """
 
         if self.using_native_model:
-            res, cost = await self.model.a_generate(prompt, schema=Reason)
+            res, cost = await self.model.a_generate(
+                prompt, schema=SummarizationScoreReason
+            )
             self.evaluation_cost += cost
             return res.reason
         else:
             try:
-                res: Reason = await self.model.a_generate(prompt, schema=Reason)
+                res: SummarizationScoreReason = await self.model.a_generate(
+                    prompt, schema=SummarizationScoreReason
+                )
                 return res.reason
             except TypeError:
                 res = await self.model.a_generate(prompt)
@@ -244,12 +264,16 @@ class SummarizationMetric(BaseMetric):
 """
 
         if self.using_native_model:
-            res, cost = self.model.generate(prompt, schema=Reason)
+            res, cost = self.model.generate(
+                prompt, schema=SummarizationScoreReason
+            )
             self.evaluation_cost += cost
             return res.reason
         else:
             try:
-                res: Reason = self.model.generate(prompt, schema=Reason)
+                res: SummarizationScoreReason = self.model.generate(
+                    prompt, schema=SummarizationScoreReason
+                )
                 return res.reason
             except TypeError:
                 res = self.model.generate(prompt)
@@ -375,16 +399,16 @@ class SummarizationMetric(BaseMetric):
         if len(original_answers) != len(summary_answers):
             raise ValueError("Number of verdicts generated does not equal.")
 
-        coverage_veridcts: List[SummarizationCoverageVerdict] = []
+        coverage_verdicts: List[SummarizationCoverageVerdict] = []
         for i in range(len(original_answers)):
-            coverage_veridcts.append(
+            coverage_verdicts.append(
                 SummarizationCoverageVerdict(
                     summary_verdict=summary_answers[i],
                     original_verdict=original_answers[i],
                     question=self.assessment_questions[i],
                 )
             )
-        return coverage_veridcts
+        return coverage_verdicts
 
     def _generate_coverage_verdicts(
         self, test_case: LLMTestCase
@@ -400,9 +424,9 @@ class SummarizationMetric(BaseMetric):
         if len(original_answers) != len(summary_answers):
             raise ValueError("Number of verdicts generated does not equal.")
 
-        coverage_veridcts: List[SummarizationCoverageVerdict] = []
+        coverage_verdicts: List[SummarizationCoverageVerdict] = []
         for i in range(len(original_answers)):
-            coverage_veridcts.append(
+            coverage_verdicts.append(
                 SummarizationCoverageVerdict(
                     summary_verdict=summary_answers[i],
                     original_verdict=original_answers[i],
@@ -410,7 +434,7 @@ class SummarizationMetric(BaseMetric):
                 )
             )
 
-        return coverage_veridcts
+        return coverage_verdicts
 
     async def _a_generate_alignment_verdicts(
         self,
@@ -420,7 +444,7 @@ class SummarizationMetric(BaseMetric):
 
         verdicts: List[SummarizationAlignmentVerdict] = []
         prompt = SummarizationTemplate.generate_alignment_verdicts(
-            summary_claims=self.claims, orignal_text="\n\n".join(self.truths)
+            summary_claims=self.claims, original_text="\n\n".join(self.truths)
         )
         if self.using_native_model:
             res, cost = await self.model.a_generate(prompt, schema=Verdicts)
@@ -451,10 +475,12 @@ class SummarizationMetric(BaseMetric):
 
         verdicts: List[SummarizationAlignmentVerdict] = []
         prompt = SummarizationTemplate.generate_alignment_verdicts(
-            summary_claims=self.claims, orignal_text="\n\n".join(self.truths)
+            summary_claims=self.claims, original_text="\n\n".join(self.truths)
         )
         if self.using_native_model:
-            res, cost = self.model.generate(prompt, schema=Verdicts)
+            res, cost = self.model.generate(
+                prompt, schema=SummarizationAlignmentVerdict
+            )
             self.evaluation_cost += cost
             verdicts = [item for item in res.verdicts]
             return verdicts
@@ -475,7 +501,8 @@ class SummarizationMetric(BaseMetric):
     async def _a_generate_truths(self, text: str) -> List[str]:
         # Borrow faithfulness template
         prompt = FaithfulnessTemplate.generate_truths(
-            text=text, extraction_limit=self.truths_extraction_limit
+            retrieval_context=text,
+            extraction_limit=self.truths_extraction_limit,
         )
         if self.using_native_model:
             res, cost = await self.model.a_generate(prompt, schema=Truths)
@@ -492,7 +519,7 @@ class SummarizationMetric(BaseMetric):
 
     async def _a_generate_claims(self, text: str) -> List[str]:
         # Borrow faithfulness template
-        prompt = FaithfulnessTemplate.generate_claims(text=text)
+        prompt = FaithfulnessTemplate.generate_claims(actual_output=text)
         if self.using_native_model:
             res, cost = await self.model.a_generate(prompt, schema=Claims)
             self.evaluation_cost += cost
@@ -509,7 +536,8 @@ class SummarizationMetric(BaseMetric):
     def _generate_truths(self, text: str) -> List[str]:
         # Borrow faithfulness template
         prompt = FaithfulnessTemplate.generate_truths(
-            text=text, extraction_limit=self.truths_extraction_limit
+            retrieval_context=text,
+            extraction_limit=self.truths_extraction_limit,
         )
         if self.using_native_model:
             res, cost = self.model.generate(prompt, schema=Truths)
@@ -526,7 +554,7 @@ class SummarizationMetric(BaseMetric):
 
     def _generate_claims(self, text: str) -> List[str]:
         # Borrow faithfulness template
-        prompt = FaithfulnessTemplate.generate_claims(text=text)
+        prompt = FaithfulnessTemplate.generate_claims(actual_output=text)
         if self.using_native_model:
             res, cost = self.model.generate(prompt, schema=Claims)
             self.evaluation_cost += cost
