@@ -1,5 +1,6 @@
 from abc import ABC, abstractmethod
 from typing import Any, Optional, List
+from deepeval.models.utils import parse_model_name
 
 
 class DeepEvalBaseModel(ABC):
@@ -8,7 +9,7 @@ class DeepEvalBaseModel(ABC):
         self.model = self.load_model(*args, **kwargs)
 
     @abstractmethod
-    def load_model(self, *args, **kwargs):
+    def load_model(self, *args, **kwargs) -> "DeepEvalBaseModel":
         """Loads a model, that will be responsible for scoring.
 
         Returns:
@@ -21,7 +22,7 @@ class DeepEvalBaseModel(ABC):
 
     @abstractmethod
     def _call(self, *args, **kwargs):
-        """Runs the model to score / ourput the model predictions.
+        """Runs the model to score / output the model predictions.
 
         Returns:
             A score or a list of results.
@@ -31,11 +32,11 @@ class DeepEvalBaseModel(ABC):
 
 class DeepEvalBaseLLM(ABC):
     def __init__(self, model_name: Optional[str] = None, *args, **kwargs):
-        self.model_name = model_name
+        self.model_name = parse_model_name(model_name)
         self.model = self.load_model(*args, **kwargs)
 
     @abstractmethod
-    def load_model(self, *args, **kwargs):
+    def load_model(self, *args, **kwargs) -> "DeepEvalBaseLLM":
         """Loads a model, that will be responsible for scoring.
 
         Returns:
@@ -76,7 +77,7 @@ class DeepEvalBaseLLM(ABC):
 
 class DeepEvalBaseMLLM(ABC):
     def __init__(self, model_name: Optional[str] = None, *args, **kwargs):
-        self.model_name = model_name
+        self.model_name = parse_model_name(model_name)
 
     @abstractmethod
     def generate(self, *args, **kwargs) -> str:
@@ -103,11 +104,12 @@ class DeepEvalBaseMLLM(ABC):
 
 class DeepEvalBaseEmbeddingModel(ABC):
     def __init__(self, model_name: Optional[str] = None, *args, **kwargs):
-        self.model_name = model_name
+        self.model_name = parse_model_name(model_name)
+
         self.model = self.load_model(*args, **kwargs)
 
     @abstractmethod
-    def load_model(self, *args, **kwargs):
+    def load_model(self, *args, **kwargs) -> "DeepEvalBaseEmbeddingModel":
         """Loads a model, that will be responsible for generating text embeddings.
 
         Returns:
@@ -152,5 +154,5 @@ class DeepEvalBaseEmbeddingModel(ABC):
         pass
 
     @abstractmethod
-    async def get_model_name(self, *args, **kwargs) -> str:
+    def get_model_name(self, *args, **kwargs) -> str:
         pass
