@@ -1,4 +1,4 @@
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, Field, AliasChoices
 from enum import Enum
 from typing import List, Optional
 
@@ -20,8 +20,30 @@ class PromptType(Enum):
     LIST = "LIST"
 
 
+class PromptVersion(BaseModel):
+    id: str
+    version: str
+    commit_message: str = Field(
+        serialization_alias="commitMessage",
+        validation_alias=AliasChoices("commit_message", "commitMessage"),
+    )
+
+
+class PromptVersionsHttpResponse(BaseModel):
+    text_versions: Optional[List[PromptVersion]] = Field(
+        None,
+        serialization_alias="textVersions",
+        validation_alias=AliasChoices("text_versions", "textVersions"),
+    )
+    messages_versions: Optional[List[PromptVersion]] = Field(
+        None,
+        serialization_alias="messagesVersions",
+        validation_alias=AliasChoices("messages_versions", "messagesVersions"),
+    )
+
+
 class PromptHttpResponse(BaseModel):
-    promptVersionId: str
+    id: str
     text: Optional[str] = None
     messages: Optional[List[PromptMessage]] = None
     interpolation_type: PromptInterpolationType = Field(
