@@ -9,16 +9,16 @@ import atexit
 import queue
 import uuid
 import os
+import json
+import time
 from openai import OpenAI
 from rich.console import Console
 from rich.progress import Progress
 
-
+from deepeval.config.settings import get_settings
 from deepeval.constants import (
     CONFIDENT_TRACE_VERBOSE,
     CONFIDENT_TRACE_FLUSH,
-    CONFIDENT_SAMPLE_RATE,
-    CONFIDENT_TRACE_ENVIRONMENT,
 )
 from deepeval.confident.api import Api, Endpoints, HttpMethods, is_confident
 from deepeval.metrics import BaseMetric
@@ -50,12 +50,16 @@ from deepeval.tracing.utils import (
     tracing_enabled,
     validate_environment,
     validate_sampling_rate,
+    dump_body_to_json_file,
+    get_deepeval_trace_mode,
 )
 from deepeval.utils import dataclass_to_dict
 from deepeval.tracing.context import current_span_context, current_trace_context
 from deepeval.tracing.types import TestCaseMetricPair
 from deepeval.tracing.api import PromptApi
 
+EVAL_DUMMY_SPAN_NAME = "evals_iterator"
+
 
 class TraceManager:
     def __init__(self):
@@ -65,25 +69,27 @@ class TraceManager:
             {}
         )  # Map of span_uuid to BaseSpan
 
+        settings = get_settings()
         # Initialize queue and worker thread for trace posting
         self._trace_queue = queue.Queue()
         self._worker_thread = None
         self._min_interval = 0.2  # Minimum time between API calls (seconds)
         self._last_post_time = 0
         self._in_flight_tasks: Set[asyncio.Task[Any]] = set()
-        self._daemon = (
-            False if os.getenv(CONFIDENT_TRACE_FLUSH) == "YES" else True
-        )
+        self._flush_enabled = bool(settings.CONFIDENT_TRACE_FLUSH)
+        self._daemon = not self._flush_enabled
 
         # trace manager attributes
         self.confident_api_key = None
         self.custom_mask_fn: Optional[Callable] = None
-        self.environment = os.environ.get(
-            CONFIDENT_TRACE_ENVIRONMENT, Environment.DEVELOPMENT.value
+        self.environment = (
+            settings.CONFIDENT_TRACE_ENVIRONMENT
+            if settings.CONFIDENT_TRACE_ENVIRONMENT is not None
+            else Environment.DEVELOPMENT.value
         )
         validate_environment(self.environment)
 
-        self.sampling_rate = os.environ.get(CONFIDENT_SAMPLE_RATE, 1)
+        self.sampling_rate = settings.CONFIDENT_SAMPLE_RATE
         validate_sampling_rate(self.sampling_rate)
         self.openai_client = None
         self.tracing_enabled = True
@@ -103,11 +109,12 @@ class TraceManager:
         queue_size = self._trace_queue.qsize()
         in_flight = len(self._in_flight_tasks)
         remaining_tasks = queue_size + in_flight
-        if os.getenv(CONFIDENT_TRACE_FLUSH) != "YES" and remaining_tasks > 0:
+
+        if not self._flush_enabled and remaining_tasks > 0:
             self._print_trace_status(
                 message=f"WARNING: Exiting with {queue_size + in_flight} abaonded trace(s).",
                 trace_worker_status=TraceWorkerStatus.WARNING,
-                description=f"Set {CONFIDENT_TRACE_FLUSH}=YES as an environment variable to flush remaining traces to Confident AI.",
+                description=f"Set {CONFIDENT_TRACE_FLUSH}=1 as an environment variable to flush remaining traces to Confident AI.",
             )
 
     def mask(self, data: Any):
@@ -179,8 +186,14 @@ class TraceManager:
             if trace.status == TraceSpanStatus.IN_PROGRESS:
                 trace.status = TraceSpanStatus.SUCCESS
 
+            mode = get_deepeval_trace_mode()
+            if mode == "gen":
+                body = self.create_trace_api(trace).model_dump(
+                    by_alias=True, exclude_none=True
+                )
+                dump_body_to_json_file(body)
             # Post the trace to the server before removing it
-            if not self.evaluating:
+            elif not self.evaluating:
                 self.post_trace(trace)
             else:
                 if self.evaluation_loop:
@@ -237,6 +250,15 @@ class TraceManager:
             # This is a child span, find its parent and add it to the parent's children
             parent_span = self.get_span_by_uuid(span.parent_uuid)
             if parent_span:
+
+                if (
+                    parent_span.name == EVAL_DUMMY_SPAN_NAME
+                ):  # ignored span for evaluation
+                    span.parent_uuid = None
+                    trace.root_spans.remove(parent_span)
+                    trace.root_spans.append(span)
+                    return
+
                 parent_span.children.append(span)
             else:
                 trace.root_spans.append(span)
@@ -274,10 +296,7 @@ class TraceManager:
         description: Optional[str] = None,
         environment: Optional[str] = None,
     ):
-        if (
-            os.getenv(CONFIDENT_TRACE_VERBOSE, "YES").upper() != "NO"
-            and self.evaluating is False
-        ):
+        if get_settings().CONFIDENT_TRACE_VERBOSE and self.evaluating is False:
             console = Console()
             message_prefix = "[dim][Confident AI Trace Log][/dim]"
             if trace_worker_status == TraceWorkerStatus.SUCCESS:
@@ -295,7 +314,7 @@ class TraceManager:
                     env_text,
                     message + ":",
                     description,
-                    f"\nTo disable dev logging, set {CONFIDENT_TRACE_VERBOSE}=NO as an environment variable.",
+                    f"\nTo disable dev logging, set {CONFIDENT_TRACE_VERBOSE}=0 as an environment variable.",
                 )
             else:
                 console.print(message_prefix, env_text, message)
@@ -401,6 +420,7 @@ class TraceManager:
                         api = Api(api_key=trace_api.confident_api_key)
                     else:
                         api = Api(api_key=self.confident_api_key)
+
                     api_response, link = await api.a_send_request(
                         method=HttpMethods.POST,
                         endpoint=Endpoints.TRACES_ENDPOINT,
@@ -415,7 +435,7 @@ class TraceManager:
                         description=link,
                         environment=self.environment,
                     )
-                elif os.getenv(CONFIDENT_TRACE_FLUSH) == "YES":
+                elif self._flush_enabled:
                     # Main thread gone → to be flushed
                     remaining_trace_request_bodies.append(body)
 
@@ -492,6 +512,7 @@ class TraceManager:
             with capture_send_trace():
                 try:
                     api = Api(api_key=self.confident_api_key)
+
                     _, link = api.send_request(
                         method=HttpMethods.POST,
                         endpoint=Endpoints.TRACES_ENDPOINT,
@@ -696,6 +717,16 @@ class TraceManager:
             api_span.input_token_count = span.input_token_count
             api_span.output_token_count = span.output_token_count
 
+            processed_token_intervals = {}
+            if span.token_intervals:
+                for key, value in span.token_intervals.items():
+                    time = to_zod_compatible_iso(
+                        perf_counter_to_datetime(key),
+                        microsecond_precision=True,
+                    )
+                    processed_token_intervals[time] = value
+                api_span.token_intervals = processed_token_intervals
+
         return api_span
 
 
@@ -936,6 +967,93 @@ def observe(
     def decorator(func):
         func_name = func.__name__  # Get func_name outside wrappers
 
+        # Async generator function
+        if inspect.isasyncgenfunction(func):
+
+            @functools.wraps(func)
+            def asyncgen_wrapper(*args, **func_kwargs):
+
+                sig = inspect.signature(func)
+                bound = sig.bind(*args, **func_kwargs)
+                bound.apply_defaults()
+
+                complete_kwargs = dict(bound.arguments)
+                if "self" in complete_kwargs:
+                    complete_kwargs["self"] = replace_self_with_class_name(
+                        complete_kwargs["self"]
+                    )
+                observer_kwargs = {
+                    "observe_kwargs": observe_kwargs,
+                    "function_kwargs": complete_kwargs,
+                }
+
+                observer = Observer(
+                    type,
+                    metrics=metrics,
+                    metric_collection=metric_collection,
+                    func_name=func_name,
+                    **observer_kwargs,
+                )
+                observer.__enter__()
+                agen = func(*args, **func_kwargs)
+
+                async def gen():
+                    try:
+                        async for chunk in agen:
+                            yield chunk
+                        observer.__exit__(None, None, None)
+                    except Exception as e:
+                        observer.__exit__(type(e), e, e.__traceback__)
+                        raise
+
+                return gen()
+
+            setattr(asyncgen_wrapper, "_is_deepeval_observed", True)
+            return asyncgen_wrapper
+
+        # Sync generator function
+        if inspect.isgeneratorfunction(func):
+
+            @functools.wraps(func)
+            def gen_wrapper(*args, **func_kwargs):
+
+                sig = inspect.signature(func)
+                bound = sig.bind(*args, **func_kwargs)
+                bound.apply_defaults()
+                complete_kwargs = dict(bound.arguments)
+
+                if "self" in complete_kwargs:
+                    complete_kwargs["self"] = replace_self_with_class_name(
+                        complete_kwargs["self"]
+                    )
+                observer_kwargs = {
+                    "observe_kwargs": observe_kwargs,
+                    "function_kwargs": make_json_serializable(complete_kwargs),
+                }
+
+                observer = Observer(
+                    type,
+                    metrics=metrics,
+                    metric_collection=metric_collection,
+                    func_name=func_name,
+                    **observer_kwargs,
+                )
+                observer.__enter__()
+                original_gen = func(*args, **func_kwargs)
+
+                def gen():
+                    try:
+                        yield from original_gen
+                        observer.__exit__(None, None, None)
+                    except Exception as e:
+                        observer.__exit__(type(e), e, e.__traceback__)
+                        raise
+
+                return gen()
+
+            setattr(gen_wrapper, "_is_deepeval_observed", True)
+            return gen_wrapper
+
         if asyncio.iscoroutinefunction(func):
 
             @functools.wraps(func)
